# Fact Sheet Mapping Between Jira Service Management and SAP LeanIX
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/fact-sheet-mapping-between-jira-service-management-and-sap-leanix#overview)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/fact-sheet-mapping-between-jira-service-management-and-sap-leanix#prerequisites)
  * [Synchronization Scope](https://help.sap.com/docs/leanix/ea/fact-sheet-mapping-between-jira-service-management-and-sap-leanix#synchronization-scope)
  * [Step 1: Start the Mapping Wizard](https://help.sap.com/docs/leanix/ea/fact-sheet-mapping-between-jira-service-management-and-sap-leanix#step-1:-start-the-mapping-wizard)
  * [Step 2: Define the Source System](https://help.sap.com/docs/leanix/ea/fact-sheet-mapping-between-jira-service-management-and-sap-leanix#step-2:-define-the-source-system)
  * [Step 3: Define Fact Sheet Type](https://help.sap.com/docs/leanix/ea/fact-sheet-mapping-between-jira-service-management-and-sap-leanix#step-3:-define-fact-sheet-type)
  * [Step 4: Define Object Type](https://help.sap.com/docs/leanix/ea/fact-sheet-mapping-between-jira-service-management-and-sap-leanix#step-4:-define-object-type)
  * [Step 5: Configure Field Mappings](https://help.sap.com/docs/leanix/ea/fact-sheet-mapping-between-jira-service-management-and-sap-leanix#step-5:-configure-field-mappings)


View all
Define which fact sheets and attributes to synchronize between Jira Service Management and SAP LeanIX.
